#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_CORRECT_FMA_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_CORRECT_FMA_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/correct_fma.hpp>

#endif
